#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://www.fs-security.com/
# last revised     : 14/04/09

softname='firestarter'
softversion='1.0.3'
packageversion='64.1'

arch='i686'
cpu='i686'

prefix=/usr

#
# log
#
(


# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://kent.dl.sourceforge.net/sourceforge/firestarter/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications/
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: GTK firewall administration tool
$softname: 
$softname: With Firestarter you will have a firewall up and running 
$softname: in minutes. After that it is up to you how deep you choose  
$softname: to go.
$softname: 
$softname: 
$softname: 
$softname: 
$softname:
$softname: 
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# configure and build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --disable-static \
	  --with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"\
      --build=$arch-slackware-linux      

    make
    make install DESTDIR=$dest

# gconf stuff
 export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
     # Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
 fi 

# add 'default' files
    cp -a \
      AUTHORS COPYING INSTALL README ChangeLog \
      $dest/usr/doc/$softname-$softversion
      
# redundant  
rm -rf $dest/usr/share/doc

# Strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# .desktop file
rm -rf $dest/usr/share/gnome
cat << "EOF" > $dest/usr/share/applications/firestarter.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Firestarter
Name[ca]=Firestarter
Name[cs]=Firestarter
Name[de]=Firestarter
Name[el]=Firestaster
Name[en_CA]=Firestarter
Name[en_GB]=Firestarter
Name[es]=Firestarter
Name[fr]=Firestarter
Name[hu]=Firestarter
Name[ja]=Firestarter
Name[nb]=Firestarter
Name[nl]=Firestarter
Name[no]=Firestarter
Name[pt]=Firestarter
Name[pt_BR]=Firestarter
Name[sq]=Firestarter
Name[sr]=Паликућа
Name[sr@Latn]=Palikuća
Name[sv]=Firestarter
Name[tr]=Firestarter
Name[uk]=Firestarter
Name[vi]=Firestarter
Name[zh_CN]=Firestarter
Name[zh_TW]=Firestarter
Comment=Desktop Firewall Tool
Comment[ca]=Eina de tallafoc Firestarter per a l'escriptori
Comment[cs]=Nástroj pro firewall
Comment[de]=Konfiguration und Überwachung der Firewall
Comment[en_CA]=Desktop Firewall Tool
Comment[en_GB]=Desktop Firewall Tool
Comment[es]=Herramienta de cortafuegos de escritorio
Comment[fr]=Outil graphique de pare-feu
Comment[hu]=Linuxos tűzfalbeállító eszköz
Comment[ja]=ファイヤーウォールのデスクトップ用ツールです
Comment[nb]=Brannveggverktøy for skrivebordet
Comment[nl]=Bureaublad firewall hulpmiddel
Comment[no]=Brannveggverktøy for skrivebordet
Comment[pt]=Ferramenta de Firewall para o Ambiente de Trabalho
Comment[pt_BR]=Ferramenta de Firewall para Desktops
Comment[sq]=Instrumenti i Desktop për Firewall
Comment[tr]=Güvenlik Duvarı Aracı
Comment[vi]=Công Cụ Tường Lửa Cho Máy Bàn
Comment[zh_CN]=桌面防火墙工具
Exec=gksu firestarter
Icon=firestarter
Terminal=false
Type=Application
StartupNotify=true
Categories=System;Application;X-Zenpanel;
X-GNOME-Bugzilla-Bugzilla=GNOME
X-GNOME-Bugzilla-Product=firestarter
EOF

# The Zenwalk launcher
mkdir -p $dest/usr/libexec
mv $dest/usr/bin/firestarter $dest/usr/libexec/firestarter
cat << "EOF" > $dest/usr/bin/firestarter
#!/bin/bash
/usr/libexec/firestarter
/usr/sbin/iptables-save > /etc/netfilter/policy.netfilter
EOF
chmod 755 $dest/usr/bin/firestarter

# Make the package freedesktop compliant
mv $dest/usr/share/pixmaps/* $dest/usr/share/icons/hicolor/48x48/apps/
rm -rf $dest/usr/share/pixmaps

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

#dep file
echo -e "alsa-lib,atk,audiofile,avahi,cairo,dbus,dbus-glib,e2fsprogs,\
esound,expat,fontconfig,freetype,gcc,gconf,glib2,glitz,gnome-keyring,\
gnome-vfs,gtk+2,libart_lgpl,libbonobo,libbonoboui,libglade,libgnome,\
libgnomecanvas,libgnomeui,libpng,libxml2,openssl,orbit2,pango,pixman,\
popt,xcb,xorg-libs,zlib" > $package.dep

#
# erase source
#
rm -rf $src
rm -rf $dest

#
# generate source file
#
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/xap/firestarter/source/build-firestarter.sh > $package.src
echo $source >>$package.src

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
